#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-th-unbox
version:              0.2.1.9
visibility:           public
id:                   vector-th-unbox-0.2.1.9-HshnlN6fUlfCoM18I8wkBT
key:                  vector-th-unbox-0.2.1.9-HshnlN6fUlfCoM18I8wkBT
license:              BSD-3-Clause
copyright:            (c) 2012-2015 Liyang HU
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Liyang HU <vector-th-unbox@liyang.hu>
stability:            experimental
homepage:             https://github.com/tsurucapital/vector-th-unbox
synopsis:             Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.

    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.

category:             Data
abi:                  03c3aa52a27e904fae2ec03a13bd7151
exposed:              True
exposed-modules:      Data.Vector.Unboxed.Deriving
import-dirs:          /usr/lib/ghc-8.10.5/site-local/vector-th-unbox-0.2.1.9
library-dirs:         /usr/lib/ghc-8.10.5/site-local/vector-th-unbox-0.2.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/vector-th-unbox-0.2.1.9
hs-libraries:         HSvector-th-unbox-0.2.1.9-HshnlN6fUlfCoM18I8wkBT
depends:
    base-4.14.2.0 template-haskell-2.16.0.0
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock

haddock-html:         /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

